# -*- coding: utf-8 -*-
# @Time    : 2020-09-15 14:37
# @Author  : xzr
# @File    : settings
# @Software: PyCharm
# @Contact : xzregg@gmail.com
# @Desc    : 

from django.utils.translation import gettext_lazy as _
from .models.query import QueryCompiler





from settings import *